Download the hourly historic weather from the dutch weather agency KNMI and localize the data to a particular lon/lat
   
Note: only works in the Netherlands
   
All copyright on the data belongs to the KNMI. 
Please see https://www.knmi.nl/nederland-nu/klimatologie/uurgegevens for more details

For a usage example, see https://gist.github.com/04dce10ccb17e1ccf74e436b9af51d76